@@ -1,6 +1,7 @@
 #!/usr/bin/env python3
 
 import os
+import sys
 
 def file_content(filename):
   if os.path.exists(filename):
@@ -17,3 +18,17 @@ def file_content(filename):
   except Exception as e:
     print(f"jinny.filter_extenions.file_content(): Failed to read from file {filename} with exception")
     raise
+
+def print_stdout(content, end:str="\n"):
+  print(content, end=end)
+  return ""
+
+def print_stderr(content, end:str="\n"):
+  sys.stderr.write(content + end)
+  sys.stderr.flush()
+  return ""
+
+def tee(content, end:str="\n"):
+  print(content + end)
+  return content
+
